InstallOptions

Struct InstallOptions 

pub struct InstallOptions<'a> {
    pub force: bool,
    pub dry_run: bool,
    pub no_prefix: bool,
    pub no_merge: bool,
    pub ignore_config: IgnoreConfig,
    pub on_file: FileCallback<'a>,
    pub platform: Option<Platform>,
    pub conflict_resolver: Option<&'a dyn ConflictResolver>,
}
Options for install/upgrade/remove operations

Fields

force: bool

Force overwrite of existing files

dry_run: bool

Don’t actually make changes, just show what would happen

no_prefix: bool

Don’t add profile prefix to file names (install/upgrade only)

no_merge: bool

Don’t merge JSON files (hooks.json, settings.json, etc.)

ignore_config: IgnoreConfig

File ignore configuration

on_file: FileCallback<'a>

Callback for file operation progress

platform: Option<Platform>

Target platform (for filtering unsupported files)

conflict_resolver: Option<&'a dyn ConflictResolver>

Strategy for resolving file conflicts (None = skip with CONFLICT report)

Implementations

Source

impl<'a> InstallOptions<'a>

pub fn new() -> Self

Create new options with defaults

pub fn force(self, force: bool) -> Self

Set force flag

pub fn dry_run(self, dry_run: bool) -> Self

Set dry_run flag

pub fn no_prefix(self, no_prefix: bool) -> Self

Set no_prefix flag

pub fn no_merge(self, no_merge: bool) -> Self

Set no_merge flag

pub fn ignore_config(self, config: IgnoreConfig) -> Self

Set ignore configuration

pub fn on_file(self, callback: FileCallback<'a>) -> Self

Set file callback

pub fn platform(self, platform: Platform) -> Self

Set target platform for filtering

pub fn conflict_resolver(self, resolver: &'a dyn ConflictResolver) -> Self

Set conflict resolver strategy

pub fn should_include_path(&self, path: &Path) -> bool

Check if a path should be included for the target platform