pub struct Installer { /* private fields */ }Implementations
Sourceimpl Installer
impl Installer
pub fn new(base_dir: PathBuf) -> Self
Sourcepub fn resolve_target(
&self,
target: Option<&Path>,
global: bool,
) -> Result<PathBuf>
pub fn resolve_target( &self, target: Option<&Path>, global: bool, ) -> Result<PathBuf>
Get target directory (either project/.claude or global ~/.claude)
Sourcepub fn install(
&self,
profile: &Profile,
target: &Path,
opts: &InstallOptions<'_>,
) -> Result<InstallResult>
pub fn install( &self, profile: &Profile, target: &Path, opts: &InstallOptions<'_>, ) -> Result<InstallResult>
Install a profile to target
Sourcepub fn diff(
&self,
profile: &Profile,
target: &Path,
ignore_config: &IgnoreConfig,
) -> Result<DiffResult>
pub fn diff( &self, profile: &Profile, target: &Path, ignore_config: &IgnoreConfig, ) -> Result<DiffResult>
Compare profile with installed files
Sourcepub fn remove(
&self,
profile: &Profile,
target: &Path,
opts: &InstallOptions<'_>,
) -> Result<(usize, usize, usize)>
pub fn remove( &self, profile: &Profile, target: &Path, opts: &InstallOptions<'_>, ) -> Result<(usize, usize, usize)>
Remove installed profile files
Sourcepub fn upgrade(
&self,
profile: &Profile,
target: &Path,
opts: &InstallOptions<'_>,
) -> Result<(usize, usize, usize, usize)>
pub fn upgrade( &self, profile: &Profile, target: &Path, opts: &InstallOptions<'_>, ) -> Result<(usize, usize, usize, usize)>
Upgrade profile files
Sourcepub fn sync_back(
&self,
profile: &Profile,
target: &Path,
ignore_config: &IgnoreConfig,
dry_run: bool,
on_file: FileCallback<'_>,
) -> Result<SyncBackResult>
pub fn sync_back( &self, profile: &Profile, target: &Path, ignore_config: &IgnoreConfig, dry_run: bool, on_file: FileCallback<'_>, ) -> Result<SyncBackResult>
Sync modified installed files back to the profile directory.
Detects files that were modified locally (compared to the profile), and copies them back into the profile, removing the profile-name prefix.