Rule module for profile customization.
Rules are simple markdown files that describe how to customize a profile. They are applied to base profiles to create new customized profiles.
Structs
- Apply
Result - Result of rule application.
- Rule
- A customization rule (single markdown file).
- Rule
Executor - Executes a rule against a profile to create a new customized profile.
- Rule
Manager - Manages rule CRUD operations.
Functions
- extract_
rule - Extract a rule from an existing profile using AI.
- generate_
rule - Generate a rule from natural language instruction.
If
rule_nameis None, the AI will generate a suitable name.