SnapshotTarget

Trait SnapshotTarget 

pub trait SnapshotTarget {
    // Required methods
    fn storage_dir(&self, base_dir: &Path) -> PathBuf;
    fn content_path(&self) -> &Path;
    fn identifier(&self) -> String;
    fn should_exclude(&self, path: &Path, base: &Path) -> bool;
    fn not_found_error(&self) -> DotAgentError;
}
Trait for types that can be snapshot targets

Required Methods

fn storage_dir(&self, base_dir: &Path) -> PathBuf

Get the storage directory for snapshots of this target

fn content_path(&self) -> &Path

Get the content path to snapshot

fn identifier(&self) -> String

Get identifier for display/messages

fn should_exclude(&self, path: &Path, base: &Path) -> bool

Check if a file should be excluded from snapshot

fn not_found_error(&self) -> DotAgentError

Error to return when source doesn’t exist

Implementors