Module rule

Module rule 

Rule module for profile customization.

Rules are simple markdown files that describe how to customize a profile. They are applied to base profiles to create new customized profiles.

Structs

ApplyResult
Result of rule application.
Rule
A customization rule (single markdown file).
RuleExecutor
Executes a rule against a profile to create a new customized profile.
RuleManager
Manages rule CRUD operations.

Functions

extract_rule
Extract a rule from an existing profile using AI.
generate_rule
Generate a rule from natural language instruction. If rule_name is None, the AI will generate a suitable name.